@@ -7,7 +7,7 @@ use Carp qw(confess);
 
 require Exporter;
 
-use Regexp::Match::Any;
+use Regexp::Any;
 
 use Data::Dumper;
 
@@ -26,9 +26,12 @@ our %EXPORT_TAGS = ( 'all' => [ qw(
 
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
-our @EXPORT = qw(profane profane_list
-);
-our $VERSION = '0.04';
+our @EXPORT = qw(
+		 profane 
+		 profane_list
+		);
+
+our $VERSION = '0.6';
 
 our $re_opt = "i";
 
